#include "customwidgets.h"

static const char* groupC = "QtEmbeddedComponents";

// Qt5WayButton
Qt5WayButton_CW::Qt5WayButton_CW(QObject* parent) : QObject(parent),
	CustomWidget<Qt5WayButton>(QLatin1String("qt5waybutton.h"),
							QLatin1String(groupC),
							tr("Qt5WayButton"))
{
}
QWidget* Qt5WayButton_CW::createWidget(QWidget* parent)
{
    Qt5WayButton *nav5way = new Qt5WayButton(parent);
    nav5way->setSkin("Beryl");
	return nav5way;
}

// QtBasicGraph
QtBasicGraph_CW::QtBasicGraph_CW(QObject* parent) : QObject(parent),
	CustomWidget<QtBasicGraph>(QLatin1String("qtbasicgraph.h"),
							QLatin1String(groupC),
							tr("QtBasicGraph"))
{
}
QWidget* QtBasicGraph_CW::createWidget(QWidget* parent)
{
	QtBasicGraph *m_graph = new QtBasicGraph(parent);
    m_graph->setStyle(new QWindowsStyle());
    m_graph->setProperty("isEmbedded", false);
    m_graph->setFocusPolicy(Qt::NoFocus);
    m_graph->setRenderHints(QPainter::Antialiasing);
    return m_graph;
}

// QtMultiSlider
QtMultiSlider_CW::QtMultiSlider_CW(QObject* parent) : QObject(parent),
	CustomWidget<QtMultiSlider>(QLatin1String("qtmultislider.h"),
							QLatin1String(groupC),
							tr("QtMultiSlider"))
{
}
QWidget* QtMultiSlider_CW::createWidget(QWidget* parent)
{
    QtMultiSlider *multiSlider = new QtMultiSlider(parent);
    multiSlider->setSkin("Beryl");
    multiSlider->setValue(70);
    return multiSlider;
}

// QtScrollDial
QtScrollDial_CW::QtScrollDial_CW(QObject* parent) : QObject(parent),
	CustomWidget<QtScrollDial>(QLatin1String("qtscrolldial.h"),
							QLatin1String(groupC),
							tr("QtScrollDial"))
{
}
QWidget* QtScrollDial_CW::createWidget(QWidget* parent)
{
    QtScrollDial *dial = new QtScrollDial(parent);
    dial->setRange(0, 100);
    dial->setValue(50);
    dial->setSkin("Beryl");
    dial->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
    return dial;
}

// QtScrollWheel
QtScrollWheel_CW::QtScrollWheel_CW(QObject* parent) : QObject(parent),
	CustomWidget<QtScrollWheel>(QLatin1String("qtscrollwheel.h"),
							QLatin1String(groupC),
							tr("QtScrollWheel"))
{
}
QWidget* QtScrollWheel_CW::createWidget(QWidget* parent)
{
    QtScrollWheel *scrollWheel = new QtScrollWheel(parent);
    scrollWheel->setRange(0, 100);
    scrollWheel->setValue(50);
    scrollWheel->setSkin("Beryl");
    return scrollWheel;
}

// QtSvgButton
QtSvgButton_CW::QtSvgButton_CW(QObject* parent) : QObject(parent),
	CustomWidget<QtSvgButton>(QLatin1String("qtsvgbutton.h"),
							QLatin1String(groupC),
							tr("QtSvgButton"))
{
}
QWidget* QtSvgButton_CW::createWidget(QWidget* parent)
{
	QtSvgButton *button = new QtSvgButton(parent);
    button->setSkin("Beryl");
    return button;
}

// QtSvgDialGauge
QtSvgDialGauge_CW::QtSvgDialGauge_CW(QObject* parent) : QObject(parent),
	CustomWidget<QtSvgDialGauge>(QLatin1String("qtsvgdialgauge.h"),
							QLatin1String(groupC),
							tr("QtSvgDialGauge"))
{
}
QWidget* QtSvgDialGauge_CW::createWidget(QWidget* parent)
{
    QtSvgDialGauge *gauge = new QtSvgDialGauge(parent);
    gauge->setSkin("Tachometer");
    gauge->setNeedleOrigin(0.486, 0.466);
    gauge->setMinimum(0);
    gauge->setMaximum(360);
    gauge->setStartAngle(-130);
    gauge->setEndAngle(133);
    gauge->setValue(0);
    gauge->setMaximumSize(200, 200);
    return gauge;
}

// QtSvgSlideSwitch
QtSvgSlideSwitch_CW::QtSvgSlideSwitch_CW(QObject* parent) : QObject(parent),
	CustomWidget<QtSvgSlideSwitch>(QLatin1String("qtsvgslideswitch.h"),
							QLatin1String(groupC),
							tr("QtSvgSlideSwitch"))
{
}
QWidget* QtSvgSlideSwitch_CW::createWidget(QWidget* parent)
{
	QtSvgSlideSwitch *slide = new QtSvgSlideSwitch(parent);
    slide->setSkin("Beryl");
    return slide;
}

// QtSvgToggleSwitch
QtSvgToggleSwitch_CW::QtSvgToggleSwitch_CW(QObject* parent) : QObject(parent),
	CustomWidget<QtSvgToggleSwitch>(QLatin1String("qtsvgtoggleswitch.h"),
							QLatin1String(groupC),
							tr("QtSvgToggleSwitch"))
{
}
QWidget* QtSvgToggleSwitch_CW::createWidget(QWidget* parent)
{
	QtSvgToggleSwitch *toggle = new QtSvgToggleSwitch(parent);
    toggle->setSkin("Beryl");
    return toggle;
}

//----------------------------------------------------------------------------------

// Collection
WidgetCollection::WidgetCollection(QObject* parent) : QObject(parent)
{
	m_plugins.push_back(new Qt5WayButton_CW(this));
	m_plugins.push_back(new QtBasicGraph_CW(this));
	m_plugins.push_back(new QtMultiSlider_CW(this));

	m_plugins.push_back(new QtScrollDial_CW(this));
	m_plugins.push_back(new QtScrollWheel_CW(this));
	m_plugins.push_back(new QtSvgButton_CW(this));

	m_plugins.push_back(new QtSvgDialGauge_CW(this));
	m_plugins.push_back(new QtSvgSlideSwitch_CW(this));
	m_plugins.push_back(new QtSvgToggleSwitch_CW(this));
}

QList<QDesignerCustomWidgetInterface*> WidgetCollection::customWidgets() const
{
	return m_plugins;
}

Q_EXPORT_PLUGIN2(QtEmbeddedComponents, WidgetCollection)






